Coverage for api/tests/test_print_info.py: 0%

# Coverage for api/tests/test_print_info.py : 0%

## 11 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 import os

2 import sys

3 import subprocess

4

5 import pytest

6 from shopyo.api.info import printinfo

7 import datetime

8

9 def test_no_args(capfd):

10 printinfo()

11 year = datetime.datetime.now().year

12 captured = capfd.readouterr()

13 assert r"""

14 / ____| |

15 | (___ | |__ ___ _ __ _ _ ___

16 \___ \| '_ \ / _ \| '_ \| | | |/ _ \

17 ____) | | | | (_) | |_) | |_| | (_) |

18 |_____/|_| |_|\___/| .__/ \__, |\___/

19 | | __/ |

20 |_| |___/

21 Copyright {year}""".format(year=datetime.datetime.now().year) in captured.out